==> moodle-1.4.3-pgsql.tgz: moodle/lang/ar/resource.php <==
<?PHP // $Id$ 
      // resource.php - created with Moodle 1.4 development (2004081200)


$string['addresource'] = ' ';
$string['chooseafile'] = '    ';
$string['configdefaulturl'] = '      URL       URL';
$string['configfilterexternalpages'] = '         (  ,       )      (      ) .          -           .';
$string['configframesize'] = '   ʡ              ';
$string['configpopup'] = '         ɡ     ';
$string['configpopupdirectories'] = '      ';
$string['configpopupheight'] = '       ɿ';
$string['configpopuplocation'] = '        ɿ';
$string['configpopupmenubar'] = '         ';
$string['configpopupresizable'] = '         ';
$string['configpopupscrollbars'] = '        ';
$string['configpopupstatus'] = '      ';
$string['configpopuptoolbar'] = '        ';
$string['configpopupwidth'] = '     ɿ';
$string['configwebsearch'] = '  URL     ء             .';
$string['directlink'] = '   ';
$string['directoryinfo'] = '     ';
$string['editingaresource'] = ' ';
$string['encryptedcode'] = ' ';
$string['example'] = '';
$string['exampleurl'] = 'http://www.example.com/somedirectory/somefile.html';
$string['fetchclienterror'] = '          (    URL)';
$string['fetcherror'] = '      .';
$string['fetchservererror'] = '          (   ) <p/>';
$string['filename'] = ' ';
$string['filtername'] = '   ';
$string['frameifpossible'] = '         ';
$string['fulltext'] = ' ';
$string['htmlfragment'] = '  HTML';
$string['maindirectory'] = '  ';
$string['modulename'] = '';
$string['modulenameplural'] = '';
$string['neverseen'] = '  ';
$string['newdirectories'] = '  ';
$string['newfullscreen'] = '  ';
$string['newheight'] = '   ()';
$string['newlocation'] = '  ';
$string['newmenubar'] = '  ';
$string['newresizable'] = '   ';
$string['newscrollbars'] = '  ';
$string['newstatus'] = '  ';
$string['newtoolbar'] = '  ';
$string['newwidth'] = '   ()';
$string['newwindow'] = ' ';
$string['newwindowopen'] = '     ';
$string['note'] = '';
$string['notefile'] = '     (   )  <a href=\"$a\">File Manager</a>.';
$string['notypechosen'] = '   .    back   .';
$string['pagedisplay'] = '     ';
$string['pagewindow'] = ' ';
$string['popupresource'] = '        ';
$string['popupresourcelink'] = '    : $a';
$string['resourcetype'] = ' ';
$string['resourcetypedirectory'] = ' ';
$string['resourcetypefile'] = '   ';
$string['resourcetypehtml'] = '  ';
$string['resourcetypelabel'] = ' ';
$string['resourcetypetext'] = '  ';
$string['searchweb'] = '   ';

?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/ar/resource.php <==
<?PHP // $Id$ 
      // resource.php - created with Moodle 1.6 development (2005052400)


$string['addresource'] = ' ';
$string['chooseafile'] = '    ';
$string['configdefaulturl'] = '      URL       URL';
$string['configfilterexternalpages'] = '         (  ,       )      (      ) .          -           .';
$string['configframesize'] = '   ʡ              ';
$string['configpopup'] = '         ɡ     ';
$string['configpopupdirectories'] = '      ';
$string['configpopupheight'] = '       ɿ';
$string['configpopuplocation'] = '        ɿ';
$string['configpopupmenubar'] = '         ';
$string['configpopupresizable'] = '         ';
$string['configpopupscrollbars'] = '        ';
$string['configpopupstatus'] = '      ';
$string['configpopuptoolbar'] = '        ';
$string['configpopupwidth'] = '     ɿ';
$string['configwebsearch'] = '  URL     ء             .';
$string['directlink'] = '   ';
$string['directoryinfo'] = '     ';
$string['display'] = '';
$string['editingaresource'] = ' ';
$string['encryptedcode'] = ' ';
$string['example'] = '';
$string['exampleurl'] = 'http://www.example.com/somedirectory/somefile.html';
$string['fetchclienterror'] = '          (    URL)';
$string['fetcherror'] = '      .';
$string['fetchservererror'] = '          (   )';
$string['filename'] = ' ';
$string['filtername'] = '   ';
$string['frameifpossible'] = '         ';
$string['fulltext'] = ' ';
$string['htmlfragment'] = '  HTML';
$string['localfile'] = ' ';
$string['localfilechoose'] = '   ( )';
$string['localfilehelp'] = '   ';
$string['localfileselect'] = '   ';
$string['maindirectory'] = '  ';
$string['modulename'] = '';
$string['modulenameplural'] = '';
$string['neverseen'] = '  ';
$string['newdirectories'] = '  ';
$string['newfullscreen'] = '  ';
$string['newheight'] = '   ()';
$string['newlocation'] = '  ';
$string['newmenubar'] = '  ';
$string['newresizable'] = '   ';
$string['newscrollbars'] = '  ';
$string['newstatus'] = '  ';
$string['newtoolbar'] = '  ';
$string['newwidth'] = '   ()';
$string['newwindow'] = ' ';
$string['newwindowopen'] = '     ';
$string['note'] = '';
$string['notefile'] = '     (   )  <a href=\"$a\">File Manager</a>.';
$string['notypechosen'] = '   .    back   .';
$string['pagedisplay'] = '     ';
$string['pagewindow'] = ' ';
$string['popupresource'] = '        ';
$string['popupresourcelink'] = '    : $a';
$string['resourcetype'] = ' ';
$string['resourcetype1'] = '';
$string['resourcetype2'] = ' ';
$string['resourcetype3'] = ' ';
$string['resourcetype4'] = '';
$string['resourcetype5'] = ' ';
$string['resourcetype6'] = '    ';
$string['resourcetype7'] = '';
$string['resourcetype8'] = '  ';
$string['resourcetype9'] = '';
$string['resourcetypedirectory'] = ' ';
$string['resourcetypefile'] = '   ';
$string['resourcetypehtml'] = '  ';
$string['resourcetypelabel'] = ' ';
$string['resourcetypetext'] = '  ';
$string['searchweb'] = '   ';
$string['serverurl'] = '   ($a->wwwroot)';
$string['variablename'] = ' ';

?>
